@@ -104,6 +104,11 @@ if ! [ "$SECURITY_GROUP" ]; then
   fi
   SECURITY_GROUP="$(ndt show-stack-params-and-outputs -r $REGION $BAKERY_ROLES_STACK -p $SG_PARAM)"
 fi
+if [ "$IMAGETYPE" != "windows" ]; then
+  [ "$IMAGE_WAIT" ] || IMAGE_WAIT=1200
+else
+  [ "$IMAGE_WAIT" ] || IMAGE_WAIT=1800
+fi
 if ! [ "$AMIBAKE_INSTANCEPROFILE" ]; then 
   [ "$INSTANCE_PROFILE_PARAM" ] || INSTANCE_PROFILE_PARAM="bakeInstanceInstanceprofile"
   AMIBAKE_INSTANCEPROFILE="$(ndt show-stack-params-and-outputs -r $REGION $BAKERY_ROLES_STACK -p $INSTANCE_PROFILE_PARAM)"
@@ -315,6 +320,7 @@ if $(which ansible-playbook) \
   -e amibake_instanceprofile=$AMIBAKE_INSTANCEPROFILE \
   -e pause_seconds=$PAUSE_SECONDS \
   -e volume_size=$VOLUME_SIZE \
+  -e image_wait=$IMAGE_WAIT \
   -e "$PASSWD_ARG"; then
 
   echo "AMI_ID=$(cat ami-id.txt)" > ami.properties
